//Config file header created by scons

#ifndef __CONFIG_H
#define __CONFIG_H
#define GCC
#define HAVE_EXR 0
#define HAVE_JPEG 1
#define HAVE_PTHREAD 1
#define HAVE_ZLIB 1
#define LIBPATH "/usr/local/lib"
#define MIN_RAYDIST 0.00005
#define PACKAGE "yafray"
#define VERSION "0.0.8"

#define __BEGIN_YAFRAY namespace yafray {
#define __END_YAFRAY }

__BEGIN_YAFRAY
typedef float CFLOAT;
typedef float GFLOAT;
typedef float PFLOAT;
__END_YAFRAY
#define YAFRAYPLUGIN_EXPORT
#define YAFRAYCORE_EXPORT
#endif
